@@ -28,6 +28,14 @@
 
 constexpr auto APPLICATION_ID = "org.kde.angelfish";
 
+QString desktopFileDirectory()
+{
+    if (!QStandardPaths::locate(QStandardPaths::RuntimeLocation, QStringLiteral("flatpak-info")).isEmpty()) {
+        return qEnvironmentVariable("HOME") % u"/.local/share/applications/";
+    }
+    return QStandardPaths::writableLocation(QStandardPaths::ApplicationsLocation);
+}
+
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
     QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
@@ -67,11 +75,13 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     }
 
     const QString fileName = parser.positionalArguments().constFirst();
-    const KDesktopFile desktopFile(fileName);
+    const QString path = desktopFileDirectory() % QDir::separator() % fileName;
+    const KDesktopFile desktopFile(path);
     if (desktopFile.readUrl().isEmpty()) {
+        qDebug() << "Failed to find url in" << path;
         return 2;
     }
-    const QString initialUrl = QUrl::fromUserInput(desktopFile.readUrl()).toString();
+    const QUrl initialUrl = QUrl::fromUserInput(desktopFile.readUrl());
 
     const QString appName = desktopFile.readName().toLower().replace(QLatin1Char(' '), QLatin1Char('-')) + QStringLiteral("-angelfish-webapp");
     KAboutData aboutData(appName.toLower(),
